{% load i18n %}

{% block subject %}
{% blocktrans %}{{ site_name }} - Your password has been successfully changed!{% endblocktrans %}
{% endblock %}

{% block text_body %}
{% trans "Your password has been changed!" %}

{% trans "Thanks for using our site!" %}

{% blocktrans %}The {{ site_name }} team{% endblocktrans %}
{% endblock text_body %}

{% block html_body %}
<p>{% trans "Your password has been changed!" %}</p>

<p>{% trans "Thanks for using our site!" %}</p>

<p>{% blocktrans %}The {{ site_name }} team{% endblocktrans %}</p>
{% endblock html_body %}
